# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.1.2 - 2025-02-24

ENH: add support for single precision (`float32`) input data

## 0.1.1 - 2025-02-23

- DEP: add support for numpy 1.x
- REL: ensure source distribution is testable and enable auto-publishing

## 0.1.0 - 2025-02-23

This is the first release. It's missing wheels and documentation.
Only source distribution is published on PyPI.
